@@ -54,6 +54,9 @@ struct key_tok ntp_keywords[] = {
 { "io",			T_Io,			FOLLBY_TOKEN },
 { "includefile",	T_Includefile,		FOLLBY_STRING },
 { "leapfile",		T_Leapfile,		FOLLBY_STRING },
+#ifdef LEAP_SMEAR
+{ "leapsmearinterval",	T_Leapsmearinterval,	FOLLBY_TOKEN },
+#endif
 { "logconfig",		T_Logconfig,		FOLLBY_STRINGS_TO_EOC },
 { "logfile",		T_Logfile,		FOLLBY_STRING },
 { "manycastclient",	T_Manycastclient,	FOLLBY_STRING },
@@ -338,7 +341,7 @@ generate_fsm(void)
 	u_short i;
 	u_short token;
 
-	/* 
+	/*
 	 * Sort ntp_keywords in alphabetical keyword order.  This is
 	 * not necessary, but minimizes nonfunctional changes in the
 	 * generated finite state machine when keywords are modified.
@@ -347,7 +350,7 @@ generate_fsm(void)
 	      sizeof(ntp_keywords[0]), compare_key_tok_text);
 
 	/*
-	 * To save space, reserve the state array entry matching each 
+	 * To save space, reserve the state array entry matching each
 	 * token number for its terminal state, so the token identifier
 	 * does not need to be stored in each state, but can be
 	 * recovered trivially.  To mark the entry reserved,
@@ -414,7 +417,7 @@ generate_fsm(void)
 		}
 
 		if (sst[i].finishes_token) {
-			snprintf(token_id_comment, 
+			snprintf(token_id_comment,
 				 sizeof(token_id_comment), "%5d %-17s",
 				 i, symbname(sst[i].finishes_token));
 			if (i != sst[i].finishes_token) {
@@ -467,8 +470,8 @@ generate_fsm(void)
 
 			snprintf(token_id_comment,
 				 sizeof(token_id_comment), "%5d %-17s",
-				 i, (initial_state == i) 
-					? "[initial state]" 
+				 i, (initial_state == i)
+					? "[initial state]"
 					: prefix);
 		}
 
@@ -496,8 +499,8 @@ generate_fsm(void)
  */
 static u_short
 create_scan_states(
-	char *	text, 
-	u_short	token, 
+	char *	text,
+	u_short	token,
 	follby	followedby,
 	u_short	prev_state
 	)
@@ -511,7 +514,7 @@ create_scan_states(
 	curr_char_s = prev_state;
 	prev_char_s = 0;
 
-	/* Find the correct position to insert the state. 
+	/* Find the correct position to insert the state.
 	 * All states should be in alphabetical order
 	 */
 	while (curr_char_s && (text[0] < sst[curr_char_s].ch)) {
@@ -519,7 +522,7 @@ create_scan_states(
 		curr_char_s = sst[curr_char_s].other_next_s;
 	}
 
-	/* 
+	/*
 	 * Check if a previously seen keyword has the same prefix as
 	 * the current keyword.  If so, simply use the state for that
 	 * keyword as my_state, otherwise, allocate a new state.
@@ -547,7 +550,7 @@ create_scan_states(
 			exit(3);
 		}
 		/* Store the next character of the keyword */
-		sst[my_state].ch = text[0]; 
+		sst[my_state].ch = text[0];
 		sst[my_state].other_next_s = curr_char_s;
 		sst[my_state].followedby = FOLLBY_NON_ACCEPTING;
 
@@ -586,7 +589,7 @@ create_scan_states(
 				return_state = my_state;
 		}
 	} else
-		sst[my_state].match_next_s = 
+		sst[my_state].match_next_s =
 		    create_scan_states(
 			&text[1],
 			token,
@@ -614,8 +617,8 @@ create_keyword_scanner(void)
 		current_keyword = ntp_keywords[i].key;
 		scanner =
 		    create_scan_states(
-			ntp_keywords[i].key, 
-			ntp_keywords[i].token, 
+			ntp_keywords[i].key,
+			ntp_keywords[i].token,
 			ntp_keywords[i].followedby,
 			scanner);
 	}
@@ -656,7 +659,7 @@ generate_token_text(void)
 		if (i > 0)
 			printf(",");
 		printf("\n\t/* %-5d %5d %20s */\t\"%s\"",
-		       id - lowest_id, id, symbname(id), 
+		       id - lowest_id, id, symbname(id),
 		       ntp_keywords[i].key);
 		i++;
 		id++;
@@ -665,7 +668,7 @@ generate_token_text(void)
 	printf("\n};\n\n");
 }
 
-	
+
 int
 compare_key_tok_id(
 	const void *a1,
@@ -748,7 +751,7 @@ symbname(
 	} else {
 		LIB_GETBUF(name);
 		snprintf(name, LIB_BUFLENGTH, "%d", token);
-	}	
+	}
 
 	return name;
 }
