@@ -1,8 +1,8 @@
-/* A Bison parser, made by GNU Bison 3.0.2.  */
+/* A Bison parser, made by GNU Bison 3.0.4.  */
 
 /* Bison interface for Yacc-like parsers in C
 
-   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989-1990, 2000-2015 Free Software Foundation, Inc.
 
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -118,123 +118,124 @@ extern int yydebug;
     T_Kod = 328,
     T_Mssntp = 329,
     T_Leapfile = 330,
-    T_Limited = 331,
-    T_Link = 332,
-    T_Listen = 333,
-    T_Logconfig = 334,
-    T_Logfile = 335,
-    T_Loopstats = 336,
-    T_Lowpriotrap = 337,
-    T_Manycastclient = 338,
-    T_Manycastserver = 339,
-    T_Mask = 340,
-    T_Maxage = 341,
-    T_Maxclock = 342,
-    T_Maxdepth = 343,
-    T_Maxdist = 344,
-    T_Maxmem = 345,
-    T_Maxpoll = 346,
-    T_Mdnstries = 347,
-    T_Mem = 348,
-    T_Memlock = 349,
-    T_Minclock = 350,
-    T_Mindepth = 351,
-    T_Mindist = 352,
-    T_Minimum = 353,
-    T_Minpoll = 354,
-    T_Minsane = 355,
-    T_Mode = 356,
-    T_Mode7 = 357,
-    T_Monitor = 358,
-    T_Month = 359,
-    T_Mru = 360,
-    T_Multicastclient = 361,
-    T_Nic = 362,
-    T_Nolink = 363,
-    T_Nomodify = 364,
-    T_Nomrulist = 365,
-    T_None = 366,
-    T_Nonvolatile = 367,
-    T_Nopeer = 368,
-    T_Noquery = 369,
-    T_Noselect = 370,
-    T_Noserve = 371,
-    T_Notrap = 372,
-    T_Notrust = 373,
-    T_Ntp = 374,
-    T_Ntpport = 375,
-    T_NtpSignDsocket = 376,
-    T_Orphan = 377,
-    T_Orphanwait = 378,
-    T_Panic = 379,
-    T_Peer = 380,
-    T_Peerstats = 381,
-    T_Phone = 382,
-    T_Pid = 383,
-    T_Pidfile = 384,
-    T_Pool = 385,
-    T_Port = 386,
-    T_Preempt = 387,
-    T_Prefer = 388,
-    T_Protostats = 389,
-    T_Pw = 390,
-    T_Randfile = 391,
-    T_Rawstats = 392,
-    T_Refid = 393,
-    T_Requestkey = 394,
-    T_Reset = 395,
-    T_Restrict = 396,
-    T_Revoke = 397,
-    T_Rlimit = 398,
-    T_Saveconfigdir = 399,
-    T_Server = 400,
-    T_Setvar = 401,
-    T_Source = 402,
-    T_Stacksize = 403,
-    T_Statistics = 404,
-    T_Stats = 405,
-    T_Statsdir = 406,
-    T_Step = 407,
-    T_Stepback = 408,
-    T_Stepfwd = 409,
-    T_Stepout = 410,
-    T_Stratum = 411,
-    T_String = 412,
-    T_Sys = 413,
-    T_Sysstats = 414,
-    T_Tick = 415,
-    T_Time1 = 416,
-    T_Time2 = 417,
-    T_Timer = 418,
-    T_Timingstats = 419,
-    T_Tinker = 420,
-    T_Tos = 421,
-    T_Trap = 422,
-    T_True = 423,
-    T_Trustedkey = 424,
-    T_Ttl = 425,
-    T_Type = 426,
-    T_U_int = 427,
-    T_Unconfig = 428,
-    T_Unpeer = 429,
-    T_Version = 430,
-    T_WanderThreshold = 431,
-    T_Week = 432,
-    T_Wildcard = 433,
-    T_Xleave = 434,
-    T_Year = 435,
-    T_Flag = 436,
-    T_EOC = 437,
-    T_Simulate = 438,
-    T_Beep_Delay = 439,
-    T_Sim_Duration = 440,
-    T_Server_Offset = 441,
-    T_Duration = 442,
-    T_Freq_Offset = 443,
-    T_Wander = 444,
-    T_Jitter = 445,
-    T_Prop_Delay = 446,
-    T_Proc_Delay = 447
+    T_Leapsmearinterval = 331,
+    T_Limited = 332,
+    T_Link = 333,
+    T_Listen = 334,
+    T_Logconfig = 335,
+    T_Logfile = 336,
+    T_Loopstats = 337,
+    T_Lowpriotrap = 338,
+    T_Manycastclient = 339,
+    T_Manycastserver = 340,
+    T_Mask = 341,
+    T_Maxage = 342,
+    T_Maxclock = 343,
+    T_Maxdepth = 344,
+    T_Maxdist = 345,
+    T_Maxmem = 346,
+    T_Maxpoll = 347,
+    T_Mdnstries = 348,
+    T_Mem = 349,
+    T_Memlock = 350,
+    T_Minclock = 351,
+    T_Mindepth = 352,
+    T_Mindist = 353,
+    T_Minimum = 354,
+    T_Minpoll = 355,
+    T_Minsane = 356,
+    T_Mode = 357,
+    T_Mode7 = 358,
+    T_Monitor = 359,
+    T_Month = 360,
+    T_Mru = 361,
+    T_Multicastclient = 362,
+    T_Nic = 363,
+    T_Nolink = 364,
+    T_Nomodify = 365,
+    T_Nomrulist = 366,
+    T_None = 367,
+    T_Nonvolatile = 368,
+    T_Nopeer = 369,
+    T_Noquery = 370,
+    T_Noselect = 371,
+    T_Noserve = 372,
+    T_Notrap = 373,
+    T_Notrust = 374,
+    T_Ntp = 375,
+    T_Ntpport = 376,
+    T_NtpSignDsocket = 377,
+    T_Orphan = 378,
+    T_Orphanwait = 379,
+    T_Panic = 380,
+    T_Peer = 381,
+    T_Peerstats = 382,
+    T_Phone = 383,
+    T_Pid = 384,
+    T_Pidfile = 385,
+    T_Pool = 386,
+    T_Port = 387,
+    T_Preempt = 388,
+    T_Prefer = 389,
+    T_Protostats = 390,
+    T_Pw = 391,
+    T_Randfile = 392,
+    T_Rawstats = 393,
+    T_Refid = 394,
+    T_Requestkey = 395,
+    T_Reset = 396,
+    T_Restrict = 397,
+    T_Revoke = 398,
+    T_Rlimit = 399,
+    T_Saveconfigdir = 400,
+    T_Server = 401,
+    T_Setvar = 402,
+    T_Source = 403,
+    T_Stacksize = 404,
+    T_Statistics = 405,
+    T_Stats = 406,
+    T_Statsdir = 407,
+    T_Step = 408,
+    T_Stepback = 409,
+    T_Stepfwd = 410,
+    T_Stepout = 411,
+    T_Stratum = 412,
+    T_String = 413,
+    T_Sys = 414,
+    T_Sysstats = 415,
+    T_Tick = 416,
+    T_Time1 = 417,
+    T_Time2 = 418,
+    T_Timer = 419,
+    T_Timingstats = 420,
+    T_Tinker = 421,
+    T_Tos = 422,
+    T_Trap = 423,
+    T_True = 424,
+    T_Trustedkey = 425,
+    T_Ttl = 426,
+    T_Type = 427,
+    T_U_int = 428,
+    T_Unconfig = 429,
+    T_Unpeer = 430,
+    T_Version = 431,
+    T_WanderThreshold = 432,
+    T_Week = 433,
+    T_Wildcard = 434,
+    T_Xleave = 435,
+    T_Year = 436,
+    T_Flag = 437,
+    T_EOC = 438,
+    T_Simulate = 439,
+    T_Beep_Delay = 440,
+    T_Sim_Duration = 441,
+    T_Server_Offset = 442,
+    T_Duration = 443,
+    T_Freq_Offset = 444,
+    T_Wander = 445,
+    T_Jitter = 446,
+    T_Prop_Delay = 447,
+    T_Proc_Delay = 448
   };
 #endif
 /* Tokens.  */
@@ -311,127 +312,128 @@ extern int yydebug;
 #define T_Kod 328
 #define T_Mssntp 329
 #define T_Leapfile 330
-#define T_Limited 331
-#define T_Link 332
-#define T_Listen 333
-#define T_Logconfig 334
-#define T_Logfile 335
-#define T_Loopstats 336
-#define T_Lowpriotrap 337
-#define T_Manycastclient 338
-#define T_Manycastserver 339
-#define T_Mask 340
-#define T_Maxage 341
-#define T_Maxclock 342
-#define T_Maxdepth 343
-#define T_Maxdist 344
-#define T_Maxmem 345
-#define T_Maxpoll 346
-#define T_Mdnstries 347
-#define T_Mem 348
-#define T_Memlock 349
-#define T_Minclock 350
-#define T_Mindepth 351
-#define T_Mindist 352
-#define T_Minimum 353
-#define T_Minpoll 354
-#define T_Minsane 355
-#define T_Mode 356
-#define T_Mode7 357
-#define T_Monitor 358
-#define T_Month 359
-#define T_Mru 360
-#define T_Multicastclient 361
-#define T_Nic 362
-#define T_Nolink 363
-#define T_Nomodify 364
-#define T_Nomrulist 365
-#define T_None 366
-#define T_Nonvolatile 367
-#define T_Nopeer 368
-#define T_Noquery 369
-#define T_Noselect 370
-#define T_Noserve 371
-#define T_Notrap 372
-#define T_Notrust 373
-#define T_Ntp 374
-#define T_Ntpport 375
-#define T_NtpSignDsocket 376
-#define T_Orphan 377
-#define T_Orphanwait 378
-#define T_Panic 379
-#define T_Peer 380
-#define T_Peerstats 381
-#define T_Phone 382
-#define T_Pid 383
-#define T_Pidfile 384
-#define T_Pool 385
-#define T_Port 386
-#define T_Preempt 387
-#define T_Prefer 388
-#define T_Protostats 389
-#define T_Pw 390
-#define T_Randfile 391
-#define T_Rawstats 392
-#define T_Refid 393
-#define T_Requestkey 394
-#define T_Reset 395
-#define T_Restrict 396
-#define T_Revoke 397
-#define T_Rlimit 398
-#define T_Saveconfigdir 399
-#define T_Server 400
-#define T_Setvar 401
-#define T_Source 402
-#define T_Stacksize 403
-#define T_Statistics 404
-#define T_Stats 405
-#define T_Statsdir 406
-#define T_Step 407
-#define T_Stepback 408
-#define T_Stepfwd 409
-#define T_Stepout 410
-#define T_Stratum 411
-#define T_String 412
-#define T_Sys 413
-#define T_Sysstats 414
-#define T_Tick 415
-#define T_Time1 416
-#define T_Time2 417
-#define T_Timer 418
-#define T_Timingstats 419
-#define T_Tinker 420
-#define T_Tos 421
-#define T_Trap 422
-#define T_True 423
-#define T_Trustedkey 424
-#define T_Ttl 425
-#define T_Type 426
-#define T_U_int 427
-#define T_Unconfig 428
-#define T_Unpeer 429
-#define T_Version 430
-#define T_WanderThreshold 431
-#define T_Week 432
-#define T_Wildcard 433
-#define T_Xleave 434
-#define T_Year 435
-#define T_Flag 436
-#define T_EOC 437
-#define T_Simulate 438
-#define T_Beep_Delay 439
-#define T_Sim_Duration 440
-#define T_Server_Offset 441
-#define T_Duration 442
-#define T_Freq_Offset 443
-#define T_Wander 444
-#define T_Jitter 445
-#define T_Prop_Delay 446
-#define T_Proc_Delay 447
+#define T_Leapsmearinterval 331
+#define T_Limited 332
+#define T_Link 333
+#define T_Listen 334
+#define T_Logconfig 335
+#define T_Logfile 336
+#define T_Loopstats 337
+#define T_Lowpriotrap 338
+#define T_Manycastclient 339
+#define T_Manycastserver 340
+#define T_Mask 341
+#define T_Maxage 342
+#define T_Maxclock 343
+#define T_Maxdepth 344
+#define T_Maxdist 345
+#define T_Maxmem 346
+#define T_Maxpoll 347
+#define T_Mdnstries 348
+#define T_Mem 349
+#define T_Memlock 350
+#define T_Minclock 351
+#define T_Mindepth 352
+#define T_Mindist 353
+#define T_Minimum 354
+#define T_Minpoll 355
+#define T_Minsane 356
+#define T_Mode 357
+#define T_Mode7 358
+#define T_Monitor 359
+#define T_Month 360
+#define T_Mru 361
+#define T_Multicastclient 362
+#define T_Nic 363
+#define T_Nolink 364
+#define T_Nomodify 365
+#define T_Nomrulist 366
+#define T_None 367
+#define T_Nonvolatile 368
+#define T_Nopeer 369
+#define T_Noquery 370
+#define T_Noselect 371
+#define T_Noserve 372
+#define T_Notrap 373
+#define T_Notrust 374
+#define T_Ntp 375
+#define T_Ntpport 376
+#define T_NtpSignDsocket 377
+#define T_Orphan 378
+#define T_Orphanwait 379
+#define T_Panic 380
+#define T_Peer 381
+#define T_Peerstats 382
+#define T_Phone 383
+#define T_Pid 384
+#define T_Pidfile 385
+#define T_Pool 386
+#define T_Port 387
+#define T_Preempt 388
+#define T_Prefer 389
+#define T_Protostats 390
+#define T_Pw 391
+#define T_Randfile 392
+#define T_Rawstats 393
+#define T_Refid 394
+#define T_Requestkey 395
+#define T_Reset 396
+#define T_Restrict 397
+#define T_Revoke 398
+#define T_Rlimit 399
+#define T_Saveconfigdir 400
+#define T_Server 401
+#define T_Setvar 402
+#define T_Source 403
+#define T_Stacksize 404
+#define T_Statistics 405
+#define T_Stats 406
+#define T_Statsdir 407
+#define T_Step 408
+#define T_Stepback 409
+#define T_Stepfwd 410
+#define T_Stepout 411
+#define T_Stratum 412
+#define T_String 413
+#define T_Sys 414
+#define T_Sysstats 415
+#define T_Tick 416
+#define T_Time1 417
+#define T_Time2 418
+#define T_Timer 419
+#define T_Timingstats 420
+#define T_Tinker 421
+#define T_Tos 422
+#define T_Trap 423
+#define T_True 424
+#define T_Trustedkey 425
+#define T_Ttl 426
+#define T_Type 427
+#define T_U_int 428
+#define T_Unconfig 429
+#define T_Unpeer 430
+#define T_Version 431
+#define T_WanderThreshold 432
+#define T_Week 433
+#define T_Wildcard 434
+#define T_Xleave 435
+#define T_Year 436
+#define T_Flag 437
+#define T_EOC 438
+#define T_Simulate 439
+#define T_Beep_Delay 440
+#define T_Sim_Duration 441
+#define T_Server_Offset 442
+#define T_Duration 443
+#define T_Freq_Offset 444
+#define T_Wander 445
+#define T_Jitter 446
+#define T_Prop_Delay 447
+#define T_Proc_Delay 448
 
 /* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE YYSTYPE;
+
 union YYSTYPE
 {
 #line 51 "ntp_parser.y" /* yacc.c:1909  */
@@ -453,8 +455,10 @@ union YYSTYPE
 	script_info *		Sim_script;
 	script_info_fifo *	Sim_script_fifo;
 
-#line 457 "../../ntpd/ntp_parser.h" /* yacc.c:1909  */
+#line 459 "../../ntpd/ntp_parser.h" /* yacc.c:1909  */
 };
+
+typedef union YYSTYPE YYSTYPE;
 # define YYSTYPE_IS_TRIVIAL 1
 # define YYSTYPE_IS_DECLARED 1
 #endif
