@@ -651,7 +651,7 @@ arc_start(
 	DPRINTF(1, ("arc: unit %d using tty_open().\n", unit));
 	fd = tty_open(device, OPEN_FLAGS, 0777);
 	if (fd < 0) {
-		msyslog(LOG_ERR, "MSF_ARCRON(%d): failed second open(%s, 0777): %m.\n",
+		msyslog(LOG_ERR, "MSF_ARCRON(%d): failed second open(%s, 0777): %m.",
 			unit, device);
 		close(temp_fd);
 		return 0;
@@ -660,14 +660,17 @@ arc_start(
 	temp_fd = -1;
 
 #ifndef SYS_WINNT
-	fcntl(fd, F_SETFL, 0); /* clear the descriptor flags */
+	if (-1 == fcntl(fd, F_SETFL, 0)) /* clear the descriptor flags */
+		msyslog(LOG_ERR, "MSF_ARCRON(%d): fcntl(F_SETFL, 0): %m.",
+			unit);
+
 #endif
 	DPRINTF(1, ("arc: opened RS232 port with file descriptor %d.\n", fd));
 
 #ifdef HAVE_TERMIOS
 
 	if (tcgetattr(fd, &arg) < 0) {
-		msyslog(LOG_ERR, "MSF_ARCRON(%d): tcgetattr(%s): %m.\n",
+		msyslog(LOG_ERR, "MSF_ARCRON(%d): tcgetattr(%s): %m.",
 			unit, device);
 		close(fd);
 		return 0;
@@ -681,7 +684,7 @@ arc_start(
 	arg.c_cc[VTIME] = 0;
 
 	if (tcsetattr(fd, TCSANOW, &arg) < 0) {
-		msyslog(LOG_ERR, "MSF_ARCRON(%d): tcsetattr(%s): %m.\n",
+		msyslog(LOG_ERR, "MSF_ARCRON(%d): tcsetattr(%s): %m.",
 			unit, device);
 		close(fd);
 		return 0;
@@ -840,7 +843,7 @@ send_slow(
 static int
 get2(char *p, int *val)
 {
-  if (!isdigit((int)p[0]) || !isdigit((int)p[1])) return 0;
+  if (!isdigit((unsigned char)p[0]) || !isdigit((unsigned char)p[1])) return 0;
   *val = (p[0] - '0') * 10 + p[1] - '0';
   return 1;
 }
@@ -848,7 +851,7 @@ get2(char *p, int *val)
 static int
 get1(char *p, int *val)
 {
-  if (!isdigit((int)p[0])) return 0;
+  if (!isdigit((unsigned char)p[0])) return 0;
   *val = p[0] - '0';
   return 1;
 }
@@ -940,7 +943,7 @@ arc_receive(
 #ifdef DEBUG
 		if(debug) { /* Show \r as `R', other non-printing char as `?'. */
 			printf("arc: stamp -->%c<-- (%d chars rcvd)\n",
-			       ((c == '\r') ? 'R' : (isgraph((int)c) ? c : '?')),
+			       ((c == '\r') ? 'R' : (isgraph((unsigned char)c) ? c : '?')),
 			       rbufp->recv_length);
 		}
 #endif
